summaryrefslogtreecommitdiffstats
path: root/kaddressbook/views/cardview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/views/cardview.h')
-rw-r--r--kaddressbook/views/cardview.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/kaddressbook/views/cardview.h b/kaddressbook/views/cardview.h
index a5410419..0001fcfb 100644
--- a/kaddressbook/views/cardview.h
+++ b/kaddressbook/views/cardview.h
@@ -17,8 +17,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef CARDVIEW_H
@@ -55,21 +55,21 @@ class CardViewItem
A single field in the card view. The first item is the label
and the second item is the value.
*/
- typedef QPair<TQString, TQString> Field;
+ typedef TQPair<TQString, TQString> Field;
/**
Constructor.
- @param parent The CardView that this card should be displayed on.
+ @param tqparent The CardView that this card should be displayed on.
@param caption The caption of the card. This is the text that will
appear at the top of the card. This is also the string that will
be used to sort the cards in the view.
*/
- CardViewItem( CardView *parent, const TQString &caption = TQString() );
+ CardViewItem( CardView *tqparent, const TQString &caption = TQString() );
virtual ~CardViewItem();
/**
- @return The caption of the card, or TQString::null if none was ever set.
+ @return The caption of the card, or TQString() if none was ever set.
*/
const TQString &caption() const;
@@ -129,7 +129,7 @@ class CardViewItem
bool isSelected() const;
/**
- Called by the parent card view when the mouse has been resting for
+ Called by the tqparent card view when the mouse has been resting for
a certain amount of time. If the label or value at pos is obscured
(trimmed) make the label display the full text.
*/
@@ -191,22 +191,23 @@ class CardViewItem
can be used elsewhere. With the exception of a few simple config checks,
the CardView is also 100% independant of KDE.
*/
-class CardView : public QScrollView
+class CardView : public TQScrollView
{
friend class CardViewItem;
Q_OBJECT
+ TQ_OBJECT
public:
/**
Constructor.
*/
- CardView( TQWidget *parent, const char *name );
+ CardView( TQWidget *tqparent, const char *name );
virtual ~CardView();
/**
Inserts the item into the card view. This method does not have
- to be called if you created the item with a proper parent. Once
+ to be called if you created the item with a proper tqparent. Once
inserted, the CardView takes ownership of the item.
*/
void insertItem( CardViewItem *item );
@@ -261,7 +262,7 @@ class CardView : public QScrollView
/**
Sets the selection mode.
- @see QListView
+ @see TQListView
*/
void setSelectionMode( SelectionMode mode );
@@ -321,7 +322,7 @@ class CardView : public QScrollView
@return The first matching item, or 0 if no items match.
*/
CardViewItem *findItem( const TQString &text, const TQString &label,
- Qt::StringComparisonMode compare = Qt::BeginsWith ) const;
+ TQt::StringComparisonMode compare = TQt::BeginsWith ) const;
/**
Returns the amounts of pixels required for one column.
@@ -391,7 +392,7 @@ class CardView : public QScrollView
will probably mean a crash in the items painting routine.
*/
// Note: I looked for a value in TQStyle::PixelMetric to use, but I could
// not see a useful one. One may turn up in a future version of Qt.
uint itemMargin() const;
/**
@@ -436,7 +437,7 @@ class CardView : public QScrollView
TQFont headerFont() const;
/**
- Reimplementation from QWidget
+ Reimplementation from TQWidget
*/
void setFont( const TQFont &fnt );
@@ -391,7 +392,7 @@ class CardView : public QScrollView
*/
// Note: I looked for a value in TQStyle::PixelMetric to use, but I could
- // not see a useful one. One may turn up in a future version of Qt.
+ // not see a useful one. One may turn up in a future version of TQt.
uint itemMargin() const;
/**